@@ -2,7 +2,7 @@
 
 __author__ = """François Durand"""
 __email__ = 'fradurand@gmail.com'
-__version__ = '0.22.0'
+__version__ = '0.23.0'
 
 
 # Utils
@@ -17,8 +17,8 @@ from poisson_approval.utils.SetPrintingInOrder import SetPrintingInOrder
 from poisson_approval.utils.Util import initialize_random_seeds, rand_simplex, rand_integers_fixed_sum, \
     rand_simplex_grid, probability, image_distribution, isnan, isposinf, isneginf, give_figure, to_callable, \
     product_dict, candidates_to_d_candidate_probability, candidates_to_probabilities, array_to_d_candidate_value, \
-    d_candidate_value_to_array, one_over_t_plus_one, one_over_sqrt_t_plus_one, one_over_log_t_plus_two, \
-    one_over_log_log_t_plus_fifteen, my_division, iterator_integers_fixed_sum, iterate_simplex_grid
+    d_candidate_value_to_array, one_over_t, one_over_sqrt_t, one_over_log_t_plus_one, \
+    one_over_log_log_t_plus_fourteen, my_division, iterator_integers_fixed_sum, iterate_simplex_grid
 from poisson_approval.utils.UtilBallots import ballot_one, ballot_two, ballot_one_two, ballot_one_three, \
     ballot_high_u, ballot_low_u, allowed_ballots
 from poisson_approval.utils.UtilCache import cached_property, DeleteCacheMixin, property_deleting_cache
