@@ -1,5 +1,5 @@
-from math import sqrt, log, pi, isclose, exp, factorial
-import numpy as np
+import sympy
+from poisson_approval.utils.computation_engine import computation_engine
 from poisson_approval.utils.Util import isnan, isneginf
 
 
@@ -9,33 +9,37 @@ class Asymptotic:
 
     Parameters
     ----------
-    mu : Number, ``np.nan`` or ``- np.inf``
+    mu : Number, ``sp.nan``, ``np.nan``, ``- sp.oo`` or ``- np.inf``
         Coefficient of the term in `n` (called "magnitude").
-    nu : Number, ``np.nan`` or ``- np.inf``
+    mu : Number, ``sp.nan``, ``np.nan``, ``- sp.oo`` or ``- np.inf``
         Coefficient of the term in `log n`.
-    xi : Number, ``np.nan`` or ``- np.inf``
+    mu : Number, ``sp.nan``, ``np.nan``, ``- sp.oo`` or ``- np.inf``
         Constant coefficient.
+    symbolic : bool
+        Whether the computations are symbolic or numeric.
 
     Attributes
     ----------
-    μ : Number, ``np.nan`` or ``- np.inf``
+    μ : Number, ``sp.nan``, ``np.nan``, ``- sp.oo`` or ``- np.inf``
         Alias for :attr:`mu`.
-    ν : Number, ``np.nan`` or ``- np.inf``
+    ν : Number, ``sp.nan``, ``np.nan``, ``- sp.oo`` or ``- np.inf``
         Alias for :attr:`nu`.
-    ξ : Number, ``np.nan`` or ``- np.inf``
+    ξ : Number, ``sp.nan``, ``np.nan``, ``- sp.oo`` or ``- np.inf``
         Alias for :attr:`xi`.
 
     Notes
     -----
-    If a coefficient is ``np.nan``, it means that it is not known. In contrast, a coefficient 0 means that there is no
-    corresponding term in the asymptotic development.
+    If a coefficient is ``sp.nan`` or ``np.nan``, it means that it is not known. In contrast, a coefficient 0 means
+    that there is no corresponding term in the asymptotic development.
 
-    If (and only if) the event is impossible, then ``mu = nu = xi = - np.inf``.
+    If (and only if) the event is impossible, then ``mu = nu = xi = - inf``. It is possible to use either ``- sp.oo``
+    or ``- np.inf``.
 
     Examples
     --------
 
-        >>> asymptotic = Asymptotic(mu=-1 / 9, nu=-1 / 2, xi=-1 / 2 * log(8 * pi / 9))
+        >>> import math
+        >>> asymptotic = Asymptotic(mu=-1 / 9, nu=-1 / 2, xi=-1 / 2 * math.log(8 * math.pi / 9))
         >>> print(asymptotic)
         exp(- 0.111111 n - 0.5 log n - 0.513473 + o(1))
         >>> asymptotic.mu
@@ -46,13 +50,12 @@ class Asymptotic:
         -0.5134734250965083
     """
 
-    def __init__(self, mu, nu, xi):
-        self.mu = mu
-        self.nu = nu
-        self.xi = xi
-        self.μ = mu
-        self.ν = nu
-        self.ξ = xi
+    def __init__(self, mu, nu, xi, symbolic=False):
+        self.symbolic = symbolic
+        self.ce = computation_engine(symbolic)
+        self.mu = self.μ = mu
+        self.nu = self.ν = nu
+        self.xi = self.ξ = xi
 
     def __repr__(self):
         """Repr.
@@ -63,6 +66,7 @@ class Asymptotic:
 
         Examples
         --------
+            >>> import numpy as np
             >>> from fractions import Fraction
             >>> Asymptotic(mu=- Fraction(1, 10), nu=np.nan, xi=3)
             Asymptotic(mu=Fraction(-1, 10), nu=nan, xi=3)
@@ -78,12 +82,48 @@ class Asymptotic:
 
         Examples
         --------
+            >>> import numpy as np
             >>> from fractions import Fraction
             >>> print(Asymptotic(mu=- Fraction(1, 10), nu=np.nan, xi=3))
             exp(- 0.1 n + ? log n + 3 + o(1))
             >>> print(Asymptotic(mu=-np.inf, nu=-np.inf, xi=-np.inf))
             exp(- inf)
         """
+        if self.symbolic:
+            return self._str_symbolic()
+        else:
+            return self._str_approximate()
+
+    def _str_symbolic(self):
+        """Auxiliary function for __str__
+        """
+        if isneginf(self.mu) and isneginf(self.nu) and isneginf(self.xi):
+            return "exp(- inf)"
+
+        def nice(x, suffix):
+            # x : coefficient, suffix : sympy expression
+            if isnan(x):
+                return ' + ?' if suffix == 1 else ' + ? %s' % suffix
+            if x == 0:
+                return ''
+            a = sympy.symbols('a')
+            result = str(a + x * suffix)
+            assert result[0:2] == 'a '
+            return result[1:]
+
+        n = sympy.symbols('n')
+        s = nice(self.mu, n) + nice(self.nu, sympy.log(n)) + nice(self.xi, 1)
+        s += ' + o(1)'
+        if s[1] == "+":
+            s = s[3:]
+        else:
+            s = s[1:]
+        s = "exp(%s)" % s
+        return s
+
+    def _str_approximate(self):
+        """Auxiliary function for __str__
+        """
         if isneginf(self.mu) and isneginf(self.nu) and isneginf(self.xi):
             return "exp(- inf)"
 
@@ -100,6 +140,7 @@ class Asymptotic:
             result += "{:.6g}".format(float(abs(x)))
             result += ' ' + suffix if suffix else ''
             return result
+
         s = nice(self.mu, 'n') + nice(self.nu, 'log n') + nice(self.xi, '')
         s += ' + o(1)'
         if s[1] == "+":
@@ -115,10 +156,11 @@ class Asymptotic:
 
     @property
     def limit(self):
-        """Number, ``np.nan`` or ``np.inf`` : Limit when `n` tends to infinity.
+        """Number, nan or infinity : Limit when `n` tends to infinity.
 
         Examples
         --------
+            >>> import numpy as np
             >>> Asymptotic(mu=-1, nu=0, xi=0).limit
             0
             >>> Asymptotic(mu=1, nu=0, xi=0).limit
@@ -128,31 +170,28 @@ class Asymptotic:
             >>> Asymptotic(mu=0, nu=-1, xi=np.nan).limit
             0
 
-        ``np.nan`` means that the limit is unknown:
-
+        ``nan`` means that the limit is unknown:
             >>> Asymptotic(mu=0, nu=0, xi=np.nan).limit
             nan
         """
         if isnan(self.mu):
-            return np.nan
+            return self.ce.nan
         elif self.mu > 0:
-            return np.inf
+            return self.ce.inf
         elif self.mu < 0:
             return 0
-        else:
-            # self.mu == 0
+        else:  # self.mu == 0
             if isnan(self.nu):
-                return np.nan
+                return self.ce.nan
             elif self.nu > 0:
-                return np.inf
+                return self.ce.inf
             elif self.nu < 0:
                 return 0
-            else:
-                # self.nu == 0:
+            else:  # self.nu == 0:
                 if isnan(self.xi):
-                    return np.nan
+                    return self.ce.nan
                 else:
-                    return exp(self.xi)
+                    return self.ce.simplify(self.ce.exp(self.xi))
 
     def __mul__(self, other):
         """Multiplication of two asymptotic developments.
@@ -168,18 +207,22 @@ class Asymptotic:
 
         Examples
         --------
+            >>> import numpy as np
             >>> print(Asymptotic(mu=42, nu=51, xi=69) * Asymptotic(mu=1, nu=2, xi=3))
             exp(43 n + 53 log n + 72 + o(1))
             >>> print(Asymptotic(mu=42, nu=51, xi=69) * Asymptotic(mu=1, nu=np.nan, xi=np.nan))
             exp(43 n + ? log n + ? + o(1))
         """
         if not isinstance(other, Asymptotic):
-            other = Asymptotic(0, 0, log(other))
-        return Asymptotic(
-            mu=0 if isclose(self.mu, -other.mu) else self.mu + other.mu,
-            nu=0 if isclose(self.nu, -other.nu) else self.nu + other.nu,
-            xi=0 if isclose(self.xi, -other.xi) else self.xi + other.xi
-        )
+            other = Asymptotic(0, 0, self.ce.log(other), symbolic=self.symbolic)
+
+        def my_addition(x, y):
+            return 0 if self.ce.look_equal(x, -y) else self.ce.simplify(x + y)
+
+        return Asymptotic(my_addition(self.mu, other.mu),
+                          my_addition(self.nu, other.nu),
+                          my_addition(self.xi, other.xi),
+                          symbolic=self.symbolic)
 
     def __rmul__(self, other):
         """
@@ -204,6 +247,7 @@ class Asymptotic:
 
         Examples
         --------
+            >>> import numpy as np
             >>> print(Asymptotic(mu=42, nu=51, xi=69) / Asymptotic(mu=1, nu=2, xi=3))
             exp(41 n + 49 log n + 66 + o(1))
             >>> print(Asymptotic(mu=42, nu=51, xi=69) / Asymptotic(mu=1, nu=np.nan, xi=np.nan))
@@ -214,12 +258,12 @@ class Asymptotic:
             exp(42 n + 51 log n + 68.3069 + o(1))
         """
         if not isinstance(other, Asymptotic):
-            other = Asymptotic(0, 0, log(other))
-        return self * Asymptotic(- other.mu, - other.nu, - other.xi)
+            other = Asymptotic(0, 0, self.ce.log(other), symbolic=self.symbolic)
+        return self * Asymptotic(- other.mu, - other.nu, - other.xi, symbolic=self.symbolic)
 
     def __rtruediv__(self, other):
         if not isinstance(other, Asymptotic):
-            other = Asymptotic(0, 0, log(other))
+            other = Asymptotic(0, 0, self.ce.log(other), symbolic=self.symbolic)
         return other / self
 
     # noinspection PyTypeChecker
@@ -251,31 +295,31 @@ class Asymptotic:
             exp(42 n + 51 log n + 3 + o(1))
         """
         if not isinstance(other, Asymptotic):
-            other = Asymptotic(0, 0, log(other))
+            other = Asymptotic(0, 0, self.ce.log(other), symbolic=self.symbolic)
         if isnan(self.mu) or isnan(other.mu):
-            return Asymptotic(np.nan, np.nan, np.nan)
-        elif isclose(self.mu, other.mu):
+            return Asymptotic(self.ce.nan, self.ce.nan, self.ce.nan, symbolic=self.symbolic)
+        elif self.ce.look_equal(self.mu, other.mu):
             mu = max(self.mu, other.mu)
             if isnan(self.nu) or isnan(other.nu):
-                return Asymptotic(mu, np.nan, np.nan)
-            elif isclose(self.nu, other.nu):
+                return Asymptotic(mu, self.ce.nan, self.ce.nan, symbolic=self.symbolic)
+            elif self.ce.look_equal(self.nu, other.nu):
                 nu = max(self.nu, other.nu)
-                xi = log(exp(self.xi) + exp(other.xi))
-                return Asymptotic(mu, nu, xi)
+                xi = self.ce.simplify(self.ce.log(self.ce.exp(self.xi) + self.ce.exp(other.xi)))
+                return Asymptotic(mu, nu, xi, symbolic=self.symbolic)
             elif self.nu > other.nu:
-                return Asymptotic(mu, self.nu, self.xi)
+                return Asymptotic(mu, self.nu, self.xi, symbolic=self.symbolic)
             else:
-                return Asymptotic(mu, other.nu, other.xi)
+                return Asymptotic(mu, other.nu, other.xi, symbolic=self.symbolic)
         elif self.mu > other.mu:
-            return Asymptotic(self.mu, self.nu, self.xi)
+            return Asymptotic(self.mu, self.nu, self.xi, symbolic=self.symbolic)
         else:
-            return Asymptotic(other.mu, other.nu, other.xi)
+            return Asymptotic(other.mu, other.nu, other.xi, symbolic=self.symbolic)
 
     def __radd__(self, other):
         return self + other
 
-    def isclose(self, other, *args, **kwargs):
-        """Test near-equality.
+    def look_equal(self, other, *args, **kwargs):
+        """Test if two asymptotic developments can reasonably be considered as equal.
 
         Parameters
         ----------
@@ -287,12 +331,13 @@ class Asymptotic:
 
         Returns
         -------
-        isclose : bool
-            True if this asymptotic development is approximately equal to `other`.
+        bool
+            True if this asymptotic development can reasonably be considered equal to `other`. Cf.
+             :meth:`ComputationEngine.look_equal`.
 
         Examples
         --------
-            >>> Asymptotic(mu=1, nu=2, xi=3).isclose(
+            >>> Asymptotic(mu=1, nu=2, xi=3).look_equal(
             ...     Asymptotic(mu=0.999999999999, nu=2.00000000001, xi=3))
             True
         """
@@ -301,13 +346,13 @@ class Asymptotic:
         some_coefficients_are_nan = (isnan(self.mu) or isnan(self.nu) or isnan(self.xi)
                                      or isnan(other.mu) or isnan(other.nu) or isnan(other.xi))
         if some_coefficients_are_nan:
-            raise ValueError('Can assert isclose only when all coefficients are known.')
-        return (isclose(self.mu, other.mu, *args, **kwargs)
-                and isclose(self.nu, other.nu, * args, ** kwargs)
-                and isclose(self.xi, other.xi, *args, **kwargs))
+            raise ValueError('Can assert look_equal only when all coefficients are known.')
+        return (self.ce.look_equal(self.mu, other.mu, *args, **kwargs)
+                and self.ce.look_equal(self.nu, other.nu, * args, ** kwargs)
+                and self.ce.look_equal(self.xi, other.xi, *args, **kwargs))
 
     @classmethod
-    def poisson_value(cls, tau, k):
+    def poisson_value(cls, tau, k, symbolic=False):
         """Asymptotic development of ``P(X = k)``, where ``X ~ Poison(tau * n)``.
 
         Parameters
@@ -316,6 +361,8 @@ class Asymptotic:
             The parameter of the Poisson distribution is ``tau * n``, where `n` tends to infinity.
         k : int
             The desired value in ``P(X = k)``.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -331,19 +378,20 @@ class Asymptotic:
             >>> print(Asymptotic.poisson_value(tau=1, k=1))
             exp(- n + log n + o(1))
             >>> from math import log
-            >>> Asymptotic.poisson_value(tau=2, k=3).isclose(
+            >>> Asymptotic.poisson_value(tau=2, k=3).look_equal(
             ...     Asymptotic(mu=-2, nu=3, xi=3 * log(2) - log(6)))
             True
         """
+        ce = computation_engine(symbolic)
         if tau == 0:
             if k == 0:
-                return cls(mu=0, nu=0, xi=0)
+                return cls(mu=0, nu=0, xi=0, symbolic=symbolic)
             else:
-                return cls(mu=-np.inf, nu=-np.inf, xi=-np.inf)
-        return cls(mu=- tau, nu=k, xi=k * log(tau) - log(factorial(k)))
+                return cls(mu=-ce.inf, nu=-ce.inf, xi=-ce.inf, symbolic=symbolic)
+        return cls(mu=- tau, nu=k, xi=ce.simplify(k * ce.log(tau) - ce.log(ce.factorial(k))), symbolic=symbolic)
 
     @classmethod
-    def poisson_x1_eq_x2_plus_k(cls, tau_1, tau_2, k):
+    def poisson_x1_eq_x2_plus_k(cls, tau_1, tau_2, k, symbolic=False):
         """Asymptotic development of ``P(X_1 = X_2 + k)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
@@ -352,6 +400,8 @@ class Asymptotic:
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
         k : int
             The desired value in ``P(X_1 = X_2 + k)``.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -367,46 +417,43 @@ class Asymptotic:
             exp(- inf)
             >>> print(Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=1, tau_2=0, k=1))
             exp(- n + log n + o(1))
-            >>> Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=2, tau_2=0, k=3).isclose(
+            >>> Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=2, tau_2=0, k=3).look_equal(
             ...     Asymptotic(mu=-2, nu=3, xi=3 * log(2) - log(6)))
             True
-            >>> Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=1, tau_2=1, k=0).isclose(
+            >>> Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=1, tau_2=1, k=0).look_equal(
             ...     Asymptotic(mu=0, nu=- 1 / 2, xi=- 1 / 2 * log(4 * pi)))
             True
-            >>> Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=1, tau_2=2, k=3).isclose(
+            >>> Asymptotic.poisson_x1_eq_x2_plus_k(tau_1=1, tau_2=2, k=3).look_equal(
             ...     Asymptotic(mu=- (1 - sqrt(2)) ** 2, nu=- 1 / 2, xi=- 1 / 2 * log(32 * pi * sqrt(2))))
             True
         """
+        ce = computation_engine(symbolic)
         if tau_1 == 0:
             if k == 0:
-                return cls(mu=- tau_2, nu=0, xi=0)
+                return cls(mu=- tau_2, nu=0, xi=0, symbolic=symbolic)
             else:
-                return cls(mu=-np.inf, nu=-np.inf, xi=-np.inf)
+                return cls(mu=-ce.inf, nu=-ce.inf, xi=-ce.inf, symbolic=symbolic)
         elif tau_2 == 0:
-            return cls(mu=- tau_1, nu=k, xi=k * log(tau_1) - log(factorial(k)))
-        elif tau_1 == tau_2:
-            # Theoretically it falls into the general case. But in practice, the general case would give mu = -0.0,
-            # which is not nice.
-            return cls(
-                mu=0,
-                nu=- 1 / 2,
-                xi=- 1 / 2 * log(4 * pi * tau_1)
-            )
+            return cls(mu=- tau_1, nu=k, xi=ce.simplify(k * ce.log(tau_1) - ce.log(ce.factorial(k))), symbolic=symbolic)
         else:
             return cls(
-                mu=- (sqrt(tau_1) - sqrt(tau_2)) ** 2,
-                nu=- 1 / 2,
-                xi=- 1 / 2 * log(4 * pi * sqrt(tau_1 * tau_2) * tau_2**k / tau_1**k)
+                mu=ce.simplify(- (ce.sqrt(tau_1) - ce.sqrt(tau_2)) ** 2),
+                nu=- ce.S(1) / 2,
+                xi=ce.simplify(- ce.S(1) / 2
+                               * ce.log(4 * ce.pi * ce.sqrt(tau_1 * tau_2) * ce.S(tau_2**k) / tau_1**k)),
+                symbolic=symbolic
             )
 
     @classmethod
-    def poisson_eq(cls, tau_1, tau_2):
+    def poisson_eq(cls, tau_1, tau_2, symbolic=False):
         """Asymptotic development of ``P(X_1 = X_2)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
         ----------
         tau_1,tau_2 : Number
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -420,20 +467,22 @@ class Asymptotic:
             exp(o(1))
             >>> print(Asymptotic.poisson_eq(tau_1=1/10, tau_2=0))
             exp(- 0.1 n + o(1))
-            >>> Asymptotic.poisson_eq(tau_1=1/10, tau_2=9/10).isclose(
+            >>> Asymptotic.poisson_eq(tau_1=1/10, tau_2=9/10).look_equal(
             ...     Asymptotic(mu=-.4, nu=-.5, xi=-.5 * log(1.2 * pi)))
             True
         """
-        return cls.poisson_x1_eq_x2_plus_k(tau_1, tau_2, 0)
+        return cls.poisson_x1_eq_x2_plus_k(tau_1, tau_2, 0, symbolic=symbolic)
 
     @classmethod
-    def poisson_one_more(cls, tau_1, tau_2):
+    def poisson_one_more(cls, tau_1, tau_2, symbolic=False):
         """Asymptotic development of ``P(X_1 = X_2 + 1)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
         ----------
         tau_1,tau_2 : Number
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -447,12 +496,11 @@ class Asymptotic:
             exp(- inf)
             >>> print(Asymptotic.poisson_one_more(tau_1=1/10, tau_2=0))
             exp(- 0.1 n + log n - 2.30259 + o(1))
-
         """
-        return cls.poisson_x1_eq_x2_plus_k(tau_1, tau_2, 1)
+        return cls.poisson_x1_eq_x2_plus_k(tau_1, tau_2, 1, symbolic=symbolic)
 
     @classmethod
-    def poisson_x1_ge_x2_plus_k(cls, tau_1, tau_2, k):
+    def poisson_x1_ge_x2_plus_k(cls, tau_1, tau_2, k, symbolic=False):
         """Asymptotic development of ``P(X_1 >= X_2 + k)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
@@ -461,6 +509,8 @@ class Asymptotic:
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
         k : int
             The desired value in ``P(X_1 >= X_2 + k)``.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -469,49 +519,55 @@ class Asymptotic:
 
         Examples
         --------
-            >>> from math import log
+            >>> from math import log, sqrt, pi
             >>> print(Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=0, tau_2=1, k=0))
             exp(- n + o(1))
             >>> print(Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=0, tau_2=1, k=1))
             exp(- inf)
             >>> print(Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=1, tau_2=0, k=0))
             exp(o(1))
-            >>> Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=1, tau_2=1, k=0).isclose(
+            >>> Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=1, tau_2=1, k=0).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=- log(2)))
             True
-            >>> Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=1, tau_2=2, k=3).isclose(Asymptotic(
+            >>> Asymptotic.poisson_x1_ge_x2_plus_k(tau_1=1, tau_2=2, k=3).look_equal(Asymptotic(
             ...     mu=- (1 - sqrt(2)) ** 2, nu=- 1 / 2,
             ...     xi=(- 1 / 2 * log(32 * pi * sqrt(2)) - log(1 - sqrt(1 / 2)))))
             True
         """
+        ce = computation_engine(symbolic)
         if tau_1 == 0:
             if k == 0:
-                return cls(mu=- tau_2, nu=0, xi=0)
+                return cls(mu=- tau_2, nu=0, xi=0, symbolic=symbolic)
             else:
-                return cls(mu=-np.inf, nu=-np.inf, xi=-np.inf)
+                return cls(mu=-ce.inf, nu=-ce.inf, xi=-ce.inf, symbolic=symbolic)
         elif tau_1 > tau_2:
             # Probability 1 => the log tends to 0.
-            return cls(mu=0, nu=0, xi=0)
+            return cls(mu=0, nu=0, xi=0, symbolic=symbolic)
         elif tau_1 == tau_2:
             # Probability 1/2 => the log tends to - log(2).
-            return cls(mu=0, nu=0, xi=- log(2))
+            return cls(mu=0, nu=0, xi=- ce.log(2), symbolic=symbolic)
         else:
             # Use the offset theorem with event X_1 = X_2, then infinite sum.
             return cls(
-                mu=- (sqrt(tau_1) - sqrt(tau_2)) ** 2,
-                nu=- 1 / 2,
-                xi=(- 1 / 2 * log(4 * pi * sqrt(tau_1 * tau_2) * tau_2**k / tau_1**k)
-                    - log(1 - sqrt(tau_1 / tau_2)))
+                mu=ce.simplify(- (ce.sqrt(tau_1) - ce.sqrt(tau_2)) ** 2),
+                nu=- ce.S(1) / 2,
+                xi=ce.simplify(
+                    - ce.S(1) / 2 * ce.log(4 * ce.pi * ce.sqrt(tau_1 * tau_2) * ce.S(tau_2**k) / tau_1**k)
+                    - ce.log(1 - ce.sqrt(ce.S(tau_1) / tau_2))
+                ),
+                symbolic=symbolic
             )
 
     @classmethod
-    def poisson_ge(cls, tau_1, tau_2):
+    def poisson_ge(cls, tau_1, tau_2, symbolic=False):
         """Asymptotic development of ``P(X_1 >= X_2)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
         ----------
         tau_1,tau_2 : Number
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -527,28 +583,30 @@ class Asymptotic:
             exp(- 0.1 n + o(1))
             >>> print(Asymptotic.poisson_ge(tau_1=1/10, tau_2=0))
             exp(o(1))
-            >>> Asymptotic.poisson_ge(tau_1=9/10, tau_2=1/10).isclose(
+            >>> Asymptotic.poisson_ge(tau_1=9/10, tau_2=1/10).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=0))
             True
-            >>> Asymptotic.poisson_ge(tau_1=3/10, tau_2=3/10).isclose(
+            >>> Asymptotic.poisson_ge(tau_1=3/10, tau_2=3/10).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=-log(2)))
             True
             >>> asymptotic = Asymptotic.poisson_ge(tau_1=1/10, tau_2=9/10)
             >>> asymptotic_eq = Asymptotic.poisson_eq(tau_1=1/10, tau_2=9/10)
-            >>> asymptotic.isclose(
+            >>> asymptotic.look_equal(
             ...     Asymptotic(mu=asymptotic_eq.mu, nu=asymptotic_eq.nu, xi=asymptotic_eq.xi + log(3/2)))
             True
         """
-        return cls.poisson_x1_ge_x2_plus_k(tau_1, tau_2, 0)
+        return cls.poisson_x1_ge_x2_plus_k(tau_1, tau_2, 0, symbolic=symbolic)
 
     @classmethod
-    def poisson_gt(cls, tau_1, tau_2):
+    def poisson_gt(cls, tau_1, tau_2, symbolic=False):
         """Asymptotic development of ``P(X_1 > X_2)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
         ----------
         tau_1,tau_2 : Number
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -564,28 +622,30 @@ class Asymptotic:
             exp(- inf)
             >>> print(Asymptotic.poisson_gt(tau_1=1/10, tau_2=0))
             exp(o(1))
-            >>> Asymptotic.poisson_gt(tau_1=9/10, tau_2=1/10).isclose(
+            >>> Asymptotic.poisson_gt(tau_1=9/10, tau_2=1/10).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=0))
             True
-            >>> Asymptotic.poisson_gt(tau_1=3/10, tau_2=3/10).isclose(
+            >>> Asymptotic.poisson_gt(tau_1=3/10, tau_2=3/10).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=-log(2)))
             True
             >>> asymptotic = Asymptotic.poisson_gt(tau_1=1/10, tau_2=9/10)
             >>> asymptotic_eq = Asymptotic.poisson_eq(tau_1=1/10, tau_2=9/10)
-            >>> asymptotic.isclose(
+            >>> asymptotic.look_equal(
             ...     Asymptotic(mu=asymptotic_eq.mu, nu=asymptotic_eq.nu, xi=asymptotic_eq.xi - log(2)))
             True
         """
-        return cls.poisson_x1_ge_x2_plus_k(tau_1, tau_2, 1)
+        return cls.poisson_x1_ge_x2_plus_k(tau_1, tau_2, 1, symbolic=symbolic)
 
     @classmethod
-    def poisson_gt_one_more(cls, tau_1, tau_2):
+    def poisson_gt_one_more(cls, tau_1, tau_2, symbolic=False):
         """Asymptotic development of ``P(X_1 > X_2 + 1)``, where ``X_i ~ Poison(tau_i * n)``.
 
         Parameters
         ----------
         tau_1,tau_2 : Number
             The parameter of the Poisson distribution of ``X_i`` is ``tau_i * n``, where `n` tends to infinity.
+        symbolic : bool
+            Whether the computations are symbolic or numeric.
 
         Returns
         -------
@@ -601,16 +661,16 @@ class Asymptotic:
             exp(- inf)
             >>> print(Asymptotic.poisson_gt_one_more(tau_1=1/10, tau_2=0))
             exp(o(1))
-            >>> Asymptotic.poisson_gt_one_more(tau_1=9/10, tau_2=1/10).isclose(
+            >>> Asymptotic.poisson_gt_one_more(tau_1=9/10, tau_2=1/10).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=0))
             True
-            >>> Asymptotic.poisson_gt_one_more(tau_1=3/10, tau_2=3/10).isclose(
+            >>> Asymptotic.poisson_gt_one_more(tau_1=3/10, tau_2=3/10).look_equal(
             ...     Asymptotic(mu=0, nu=0, xi=-log(2)))
             True
             >>> asymptotic = Asymptotic.poisson_gt_one_more(tau_1=1/10, tau_2=9/10)
             >>> asymptotic_eq = Asymptotic.poisson_eq(tau_1=1/10, tau_2=9/10)
-            >>> asymptotic.isclose(
+            >>> asymptotic.look_equal(
             ...     Asymptotic(mu=asymptotic_eq.mu, nu=asymptotic_eq.nu, xi=asymptotic_eq.xi - log(6)))
             True
         """
-        return cls.poisson_x1_ge_x2_plus_k(tau_1, tau_2, 2)
+        return cls.poisson_x1_ge_x2_plus_k(tau_1, tau_2, 2, symbolic=symbolic)
