@@ -543,17 +543,3 @@ well_informed_voters=False, ratio_fanatic=Fraction(1, 10))
             return t, '$r(%s)$' % t
         else:
             return cls.order_and_label_weak(t)
-
-    @classmethod
-    def random_strategy(cls, **kwargs):
-        """Random strategy.
-
-        This is a default factory of random strategies. It is used, for example, in
-        :class:`ProfileCardinal.iterated_voting`.
-
-        Returns
-        -------
-        StrategyOrdinal
-            Uses :class:`RandStrategyOrdinalUniform`.
-        """
-        return RandStrategyOrdinalUniform(**kwargs)()
